@@ -22,6 +22,7 @@ from typing import List, Optional, Sequence, Tuple
 from picosvg.svg_meta import (
     number_or_percentage,
     ntos,
+    splitns,
     strip_ns,
     svgns,
     xlinkns,
@@ -189,9 +190,16 @@ class SVG:
 
     def view_box(self) -> Optional[Rect]:
         raw_box = self.svg_root.attrib.get("viewBox", None)
+        if not raw_box:
+            # if there is no explicit viewbox try to use width/height
+            w = self.svg_root.attrib.get("width", None)
+            h = self.svg_root.attrib.get("height", None)
+            if w and h:
+                return Rect(0, 0, float(w), float(h))
+
         if not raw_box:
             return None
-        box = tuple(int(v) for v in re.split(r",|\s+", raw_box))
+        box = tuple(float(v) for v in re.split(r",|\s+", raw_box))
         if len(box) != 4:
             raise ValueError("Unable to parse viewBox")
         return Rect(*box)
@@ -274,7 +282,17 @@ class SVG:
         return self.xpath_one(f'//svg:{el_tag}[@id="{match.group(1)}"]')
 
     def _resolve_use(self, scope_el):
-        attrib_not_copied = {"x", "y", "width", "height", _xlink_href_attr_name()}
+        attrib_not_copied = {
+            "x",
+            "y",
+            "width",
+            "height",
+            "transform",
+            _xlink_href_attr_name(),
+        }
+
+        # capture elements by id so even if we change it they remain stable
+        el_by_id = {el.attrib["id"]: el for el in self.xpath(".//svg:*[@id]")}
 
         while True:
             swaps = []
@@ -285,18 +303,32 @@ class SVG:
                 ref = use_el.attrib.get(_xlink_href_attr_name(), "")
                 if not ref.startswith("#"):
                     raise ValueError(f"Only use #fragment supported, reject {ref}")
-                target = self.xpath_one(f'//svg:*[@id="{ref[1:]}"]')
+
+                target = el_by_id.get(ref[1:], None)
+                if target is None:
+                    raise ValueError(f"No element has id '{ref[1:]}'")
 
                 new_el = copy.deepcopy(target)
+                # leaving id's on <use> instantiated content is a path to duplicate ids
+                for el in new_el.getiterator("*"):
+                    if "id" in el.attrib:
+                        del el.attrib["id"]
 
                 group = etree.Element(f"{{{svgns()}}}g", nsmap=self.svg_root.nsmap)
-                use_x = use_el.attrib.get("x", 0)
-                use_y = use_el.attrib.get("y", 0)
-                if use_x != 0 or use_y != 0:
-                    group.attrib["transform"] = (
-                        group.attrib.get("transform", "")
-                        + f" translate({use_x}, {use_y})"
-                    ).strip()
+                affine = Affine2D.identity().translate(
+                    float(use_el.attrib.get("x", 0)), float(use_el.attrib.get("y", 0))
+                )
+
+                if "transform" in use_el.attrib:
+                    affine = Affine2D.compose_ltr(
+                        (
+                            affine,
+                            Affine2D.fromstring(use_el.attrib["transform"]),
+                        )
+                    )
+
+                if affine != Affine2D.identity():
+                    group.attrib["transform"] = affine.tostring()
 
                 for attr_name in use_el.attrib:
                     if attr_name in attrib_not_copied:
@@ -310,9 +342,6 @@ class SVG:
                     swaps.append((use_el, new_el))
 
             for old_el, new_el in swaps:
-                # leaving id's on <use> instantiated content is a path to duplicate ids
-                for new_el_with_id in self.xpath("//svg:*[@id]", el=new_el):
-                    del new_el_with_id.attrib["id"]
                 old_el.getparent().replace(old_el, new_el)
 
     def resolve_use(self, inplace=False):
@@ -732,6 +761,47 @@ class SVG:
 
         return self
 
+    def remove_nonsvg_content(self, inplace=False):
+        if not inplace:
+            svg = SVG(copy.deepcopy(self.svg_root))
+            svg.remove_nonsvg_content(inplace=True)
+            return svg
+
+        self._update_etree()
+
+        good_ns = {svgns(), xlinkns()}
+        if self.svg_root.nsmap[None] == svgns():
+            good_ns.add(None)
+
+        el_to_rm = []
+        for el in self.svg_root.getiterator("*"):
+            attr_to_rm = []
+            ns, _ = splitns(el.tag)
+            if ns not in good_ns:
+                el_to_rm.append(el)
+                continue
+            for attr in el.attrib:
+                ns, _ = splitns(attr)
+                if ns not in good_ns:
+                    attr_to_rm.append(attr)
+            for attr in attr_to_rm:
+                del el.attrib[attr]
+
+        for el in el_to_rm:
+            el.getparent().remove(el)
+
+        # Make svg default; destroy anything unexpected
+        good_nsmap = {
+            None: svgns(),
+            "xlink": xlinkns(),
+        }
+        if any(good_nsmap.get(k, None) != v for k, v in self.svg_root.nsmap.items()):
+            self.svg_root = _copy_new_nsmap(self.svg_root, good_nsmap)
+
+        self.elements = None
+
+        return self
+
     def remove_comments(self, inplace=False):
         if not inplace:
             svg = SVG(copy.deepcopy(self.svg_root))
@@ -760,6 +830,20 @@ class SVG:
 
         return self
 
+    def remove_title_meta_desc(self, inplace=False):
+        if not inplace:
+            svg = SVG(copy.deepcopy(self.svg_root))
+            svg.remove_title_meta_desc(inplace=True)
+            return svg
+
+        self._update_etree()
+
+        for tag in ("title", "desc", "metadata"):
+            for el in self.xpath(f"//svg:{tag}"):
+                el.getparent().remove(el)
+
+        return self
+
     def set_attributes(self, name_values, xpath="/svg:svg", inplace=False):
         if not inplace:
             svg = SVG(copy.deepcopy(self.svg_root))
@@ -947,8 +1031,10 @@ class SVG:
 
         self._update_etree()
 
+        self.remove_nonsvg_content(inplace=True)
         self.remove_comments(inplace=True)
         self.remove_anonymous_symbols(inplace=True)
+        self.remove_title_meta_desc(inplace=True)
         self.apply_style_attributes(inplace=True)
         self.shapes_to_paths(inplace=True)
         self.resolve_use(inplace=True)
