@@ -17,11 +17,13 @@
 Focuses on converting to a sequence of affine matrices.
 """
 import collections
+from functools import reduce
 from math import cos, sin, radians, tan
 import re
-from typing import NamedTuple, Tuple
+from typing import NamedTuple, Sequence, Tuple
 from sys import float_info
 from picosvg.geometric_types import Point, Rect, Vector
+from picosvg.svg_meta import ntos
 
 
 _SVG_ARG_FIXUPS = collections.defaultdict(
@@ -48,6 +50,10 @@ class Affine2D(NamedTuple):
     e: float
     f: float
 
+    @staticmethod
+    def flip_y():
+        return Affine2D._flip_y
+
     @staticmethod
     def identity():
         return Affine2D._identity
@@ -60,6 +66,11 @@ class Affine2D(NamedTuple):
     def fromstring(raw_transform):
         return parse_svg_transform(raw_transform)
 
+    def tostring(self):
+        if self == Affine2D.identity().translate(*self.gettranslate()):
+            return f'translate({", ".join(ntos(v) for v in self.gettranslate())})'
+        return f'matrix({" ".join(ntos(v) for v in self)})'
+
     @staticmethod
     def product(first: "Affine2D", second: "Affine2D") -> "Affine2D":
         """Returns the product of first x second.
@@ -145,9 +156,22 @@ class Affine2D(NamedTuple):
         x, y = vec
         return Vector(self.a * x + self.c * y, self.b * x + self.d * y)
 
+    @classmethod
+    def compose_ltr(cls, affines: Sequence["Affine2D"]) -> "Affine2D":
+        """Creates merged transform equivalent to applying transforms left-to-right order.
+
+        Affines apply like functions - f(g(x)) - so we merge them in reverse order.
+        """
+        return reduce(
+            lambda acc, a: cls.product(a, acc), reversed(affines), cls.identity()
+        )
+
+    def round(self, digits: int) -> "Affine2D":
+        return Affine2D(*(round(v, digits) for v in self))
+
     @classmethod
     def rect_to_rect(cls, src: Rect, dst: Rect) -> "Affine2D":
-        """ Return Affine2D set to scale and translate src Rect to dst Rect.
+        """Return Affine2D set to scale and translate src Rect to dst Rect.
         The mapping completely fills dst, it does not preserve aspect ratio.
         """
         if src.empty():
@@ -163,6 +187,7 @@ class Affine2D(NamedTuple):
 
 Affine2D._identity = Affine2D(1, 0, 0, 1, 0, 0)
 Affine2D._degnerate = Affine2D(0, 0, 0, 0, 0, 0)
+Affine2D._flip_y = Affine2D(1, 0, 0, -1, 0, 0)
 
 
 def _fix_rotate(args):
@@ -171,16 +196,12 @@ def _fix_rotate(args):
 
 def parse_svg_transform(raw_transform: str):
     # much simpler to read if we do stages rather than a single regex
+    # one day it might be worth writing a real parser
     transform = Affine2D.identity()
 
-    svg_transforms = re.split(r"(?<=[)])\s*[,\s]\s*(?=\w)", raw_transform)
-    for svg_transform in svg_transforms:
-        match = re.match(
-            r"(?i)(matrix|translate|scale|rotate|skewX|skewY)\((.*)\)", svg_transform
-        )
-        if not match:
-            raise ValueError(f"Unable to parse {raw_transform}")
-
+    for match in re.finditer(
+        r"(?i)(matrix|translate|scale|rotate|skewX|skewY)\s*\(([^)]*)\)", raw_transform
+    ):
         op = match.group(1).lower()
         args = [float(p) for p in re.split(r"\s*[,\s]\s*", match.group(2))]
         _SVG_ARG_FIXUPS[op](args)
