@@ -48,12 +48,24 @@ from typing import Tuple
             "translate(50 90),rotate(-45) translate(130,160)",
             Affine2D(0.707, -0.707, 0.707, 0.707, 255.061, 111.213),
         ),
+        # example from Noto
+        (
+            "rotate(150)translate(0,6)rotate(66)",
+            Affine2D(a=-0.809, b=-0.588, c=0.588, d=-0.809, e=-2.999, f=-5.196),
+        ),
+        # Crafted example
+        (
+            # "rotate (180)\ttranslate\t(0 6)\n\t",
+            "rotate (180)\ttranslate(0 6)\n\t",
+            Affine2D(-1, 0, 0, -1, 0, -6),
+        ),
     ],
 )
 def test_parse_svg_transform(transform: str, expected_result: Tuple[str, ...]):
     actual = parse_svg_transform(transform)
     print(f"A: {actual}")
     print(f"E: {expected_result}")
+
     assert actual == pytest.approx(expected_result, 3)
 
 
@@ -81,7 +93,23 @@ class TestAffine2D:
 
     def test_is_degenerate(self):
         assert not Affine2D(1, 2, 3, 4, 5, 6).is_degenerate()
+        assert not Affine2D.identity().is_degenerate()
+        assert Affine2D.degenerate().is_degenerate()
         assert Affine2D(-1, 2 / 3, 3 / 2, -1, 0, 0).is_degenerate()
+        assert Affine2D(
+            float_info.epsilon,
+            float_info.epsilon,
+            float_info.epsilon,
+            float_info.epsilon,
+            0,
+            0,
+        ).is_degenerate()
+
+    def test_scale_0_is_degenerate(self):
+        assert not Affine2D.identity().scale(1, 1).is_degenerate()
+        assert Affine2D.identity().scale(0, 1).is_degenerate()
+        assert Affine2D.identity().scale(1, 0).is_degenerate()
+        assert Affine2D.identity().scale(0, 0).is_degenerate()
 
     def test_inverse(self):
         t = Affine2D.identity().translate(2, 3).scale(4, 5)
@@ -91,8 +119,9 @@ class TestAffine2D:
         p2 = it.map_point(p1)
         assert p2 == p0
 
-        with pytest.raises(ValueError, match="non-invertible"):
-            Affine2D(1, 1, 1, 1, 0, 0).inverse()
+        assert Affine2D.degenerate().inverse() == Affine2D.degenerate()
+        t = Affine2D(1, 1, 1, 1, 0, 0).inverse()
+        assert t.is_degenerate()
 
     @pytest.mark.parametrize(
         "src, dest, expected",
